VariantOrder

Trait VariantOrder 

pub trait VariantOrder {
    // Required method
    fn order() -> &'static [&'static str];
}
Trait for getting the canonical ordering of an enum’s variants.

Required Methods

fn order() -> &'static [&'static str]

Returns the variant names of the enum in order.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors